@@ -187,7 +187,7 @@ static ssize_t read_net_internal(int fd, void *buf, size_t count, int socketStat
 	return(retval);
 }
 
-static int open_net_http(char *user, char *pass, char *host, int port, char *path, int flags, off_t offset, ssize_t *length) {
+static int open_net_http(char *user, char *pass, char *host, int port, char *path, int flags, off_t offset, off_t *length) {
 	unsigned long long content_length = 0;
 	ssize_t read_ret, sink_bytes = 0;
 	ssize_t send_ret, recv_ret;
@@ -208,7 +208,7 @@ static int open_net_http(char *user, char *pass, char *host, int port, char *pat
 	if (offset == 0) {
 		snprintf_ret = snprintf(httpcmd, sizeof(httpcmd), "GET /%s HTTP/1.0\015\012Host: %s\015\012\015\012", path, host);
 	} else {
-		snprintf_ret = snprintf(httpcmd, sizeof(httpcmd), "GET /%s HTTP/1.0\015\012Host: %s\015\012Range: bytes=%lu-\015\012\015\012", path, host, (unsigned long) offset);
+		snprintf_ret = snprintf(httpcmd, sizeof(httpcmd), "GET /%s HTTP/1.0\015\012Host: %s\015\012Range: bytes=%llu-\015\012\015\012", path, host, (unsigned long long) offset);
 	}
 
 	if (snprintf_ret >= sizeof(httpcmd)) {
@@ -262,7 +262,7 @@ static int open_net_http(char *user, char *pass, char *host, int port, char *pat
 					if (strncasecmp(httpreply, "Content-Length:", 15) == 0) {
 						content_length = strtoull(httpreply + 16, NULL, 10);
 						if (offset != 0 && http_response_code == 206) {
-							content_length += offset;
+							content_length += (unsigned long long) offset;
 						}
 						if (length) {
 							*length = content_length;
@@ -315,11 +315,11 @@ static int open_net_http(char *user, char *pass, char *host, int port, char *pat
 	return(fd);
 }
 
-static int open_net_ftp(char *user, char *pass, char *host, int port, char *path, int flags, off_t offset, ssize_t *length) {
+static int open_net_ftp(char *user, char *pass, char *host, int port, char *path, int flags, off_t offset, off_t *length) {
 	return(-1);
 }
 
-static int open_net_internal(const char *pathname, int flags, mode_t mode, int *socket, off_t offset, ssize_t *length) {
+static int open_net_internal(const char *pathname, int flags, mode_t mode, int *socket, off_t offset, off_t *length) {
 	char *pathname_dup;
 	char *scheme, *user, *pass, *host, *path;
 	off_t lseek_ret;
@@ -408,7 +408,7 @@ static int open_net_internal(const char *pathname, int flags, mode_t mode, int *
 NETFILE *fopen_net(const char *pathname, const char *mode) {
 	NETFILE *ret;
 	int is_sock;
-	ssize_t length;
+	off_t length;
 
 	ret = malloc(sizeof(*ret));
 
@@ -629,6 +629,25 @@ int fclose_net(NETFILE *stream) {
 	return(retval);
 }
 
+int setvbuf_net(NETFILE *stream, char *buf, int mode, size_t size) {
+	if (!stream) {
+		return(-1);
+	}
+
+	if (size < stream->bufused) {
+		return(-1);
+	}
+
+	memcpy(buf, stream->buf, stream->bufused);
+
+	stream->buf = buf;
+	stream->buf_s = buf;
+	stream->bufsize = size;
+	stream->bufsize_s = size;
+
+	return(0);
+}
+
 int open_net(const char *pathname, int flags, mode_t mode) {
 	int tmp;
 
@@ -645,9 +664,9 @@ off_t lseek_net(int filedes, off_t offset, int whence) {
 
 int fseeko_net(NETFILE *stream, off_t offset, int whence) {
 	static char garbage[4096];
-	ssize_t newlength;
 	size_t fread_ret, bytes_to_read;
 	off_t newoffset, lseek_ret;
+	off_t newlength;
 	int newfd;
 
 	if (!stream) {
