@@ -80,7 +80,10 @@ int fseeko_net(NETFILE *stream, off_t offset, int whence);
 /* ANSI ftello() clone */
 off_t ftello_net(NETFILE *stream);
 
-/* Return the length of a stream, if possible. -1 if not available */
+/* ANSI setvbuf() clone */
+int setvbuf_net(NETFILE *stream, char *buf, int mode, size_t size);
+
+/* Return the length of a stream, if possible. ((off_t) -1) if not available */
 off_t flength_net(NETFILE *stream);
 
 #ifdef  __cplusplus
